@@ -11,7 +11,7 @@ from tornado.template import Loader
 
 from .servefiles import DirectoryHandler
 from .sql import SQLX
-from ..configuration import PlotmanConfig, get_dash_v1,get_dash_v1_static
+from ..configuration import PlotmanConfig, get_dash_v1
 
 __author__ = 'lousvicton'
 
@@ -22,6 +22,8 @@ except ImportError:
 
 
 def PostDat(dp: dict, cfg: PlotmanConfig):
+
+
     # sending post request and saving response as response object
     payload = json.dumps(dp)
     requests.post(url=f'http://{cfg.apis.target}:{cfg.apis.port}/report', data=payload)
@@ -47,25 +49,6 @@ class ApiBase(web.RequestHandler):
         self.write(json.dumps(response))
 
 
-"""
-
-from prometheus_client.core import GaugeMetricFamily
-
-class PlotmanCollector:
-    def collect(self):
-        cfg = configuration.get_validated_configs()
-        jobs = Job.genTasks(cfg.directories.log)
-        count = len(sorted(jobs, key=job.Job.get_time_wall))
-        yield GaugeMetricFamily("plotman_jobs_count", "Number of plotting jobs running", value=count)
-
-if __name__ == "__main__":
-    start_http_server(8001)
-    REGISTRY.register(PlotmanCollector())
-    while True:
-        time.sleep(1)
-"""
-
-
 class NodeHandle(web.RequestHandler):
     def initialize(self, *args, **kwargs):
         self.remote_ip = self.request.headers.get('X-Forwarded-For', self.request.headers.get('X-Real-Ip', self.request.remote_ip))
@@ -133,20 +116,6 @@ class ApiV1Review(ApiBase):
         }
         self.write(json.dumps(routes))
 
-
-"""class FrontEndLoad(web.RequestHandler):
-    def initialize(self, *args, **kwargs):
-        self.ver = pkg_resources.get_distribution('plotmanx').version
-        self.remote_ip = self.request.headers.get('X-Forwarded-For', self.request.headers.get('X-Real-Ip', self.request.remote_ip))
-        self.using_ssl = (self.request.headers.get('X-Scheme', 'http') == 'https')
-
-    def get(self):
-        # self.set_header("Content-Type", "text/plain")
-        self.render("index.html", messages=None, version=self.ver)
-
-"""
-
-
 class WebpHandler(web.StaticFileHandler):
     def write_error(self, status_code, **kwargs):
 
