@@ -1,8 +1,16 @@
 import sqlite3
+from datetime import datetime
 
 from ..configuration import get_db_path
 
 
+def txtBlock(s: any) -> str:
+    if s:
+        return str(s)
+    else:
+        return ""
+
+
 def commaInt(x: str) -> int:
     return int(x.replace(',', ''))
 
@@ -23,19 +31,29 @@ class SQLX:
                            ip text NOT NULL
                    );''')
 
-        self.cur.execute('''CREATE TABLE IF NOT EXISTS sysio (
+        self.cur.execute('''CREATE TABLE IF NOT EXISTS nodeInfo (
+        
+                                   
                                    tid INTEGER PRIMARY KEY AUTOINCREMENT,
-                                   ip text NOT NULL,
-                                   plotc INTEGER NOT NULL,
-                                   mvplotc INTEGER NOT NULL,
+                                   host text NOT NULL,
+                                   
+                                   
+                                   tmp_plots INTEGER NOT NULL,
+                                   mv_channels INTEGER NOT NULL,
                                    cpu_count INTEGER NOT NULL,
                                    cpu_percent REAL NOT NULL,
-                                   cache_percent REAL NOT NULL,
-                                   slab_percent REAL NOT NULL,
+                                   bucket_sum_t REAL NOT NULL,
+                                   bucket_count INTEGER NOT NULL,
+                                   
                                    swap_percent REAL NOT NULL,
-                                   disk_percent REAL NOT NULL,
-                                   iowait_percent REAL NOT NULL,
+                                   disk_percent_block text NOT NULL,
+                                   io_nvme_block text NOT NULL,
+                                   io_list_plmo text NOT NULL,
+                                   io_list_nfs text NOT NULL,
+                                   io_read_issues INTEGER NOT NULL,
+                                   
                                    memory_percent REAL NOT NULL,
+                                                                      
                                    net_read_mb_s INTEGER NOT NULL,
                                    net_write_mb_s INTEGER NOT NULL,
                                    disk_read_mb_s INTEGER NOT NULL,
@@ -43,8 +61,10 @@ class SQLX:
 
                                    net_fds INTEGER NOT NULL,
                                    version text NOT NULL,
-                                   stamp INTEGER NOT NULL
-
+                                   chia_ver text NOT NULL,
+                                   timen INTEGER NOT NULL
+                                   
+                                
                            );''')
 
         self.cur.execute('''CREATE TABLE IF NOT EXISTS plot (
@@ -59,7 +79,7 @@ class SQLX:
                            time text NOT NULL
                    );''')
 
-    def datainput(self, j: dict, ipremo: str, ts: str) -> None:
+    def datainput(self, j: dict, hostname: str, ts: str) -> None:
 
         if len(j['jobls']) > 0:
 
@@ -77,12 +97,13 @@ class SQLX:
                     """
 
                     (n,) = self.cur.execute(content_find).fetchone()
+
                     if int(n) == 0:
                         content_insert = f"""
                             INSERT INTO plot (plotid, k, r, b, u, pid, ip, time)
                             VALUES (
                             '{plotid}', {int(h['k'])}, {int(h['r'])}, {int(h['b'])},
-                            {int(h['u'])}, {int(h['pid'])}, '{ipremo}', '{ts}'
+                            {int(h['u'])}, {int(h['pid'])}, '{hostname}', '{ts}'
                             )
                            ;
                         """
@@ -104,39 +125,61 @@ class SQLX:
         else:
             print("body is not empty")
 
-        content_insert = f"""
-        INSERT INTO sysio (
-            ip,plotc,mvplotc,cpu_count,cpu_percent,cache_percent,slab_percent,
-            swap_percent,disk_percent,iowait_percent,memory_percent,
-            net_read_mb_s,net_write_mb_s,disk_read_mb_s,disk_write_mb_s,
-            net_fds,version,stamp
-        ) VALUES(
-            '{ipremo}',
-            {int(j['plotcount'])},
-            {int(j['movingcount'])},
-            {int(j['cpucount'])},
-            {float(j['cpu_percent'])},
-            {float(j['cache_percent'])},
-            {float(j['slab_percent'])},
-            {float(j['swap_percent'])},
-            {float(j['disk_percent'])},
-            {float(j['iowait_percent'])},
-            {float(j['memory_percent'])},
-            {commaInt(j['net_read_mb_s'])},
-            {commaInt(j['net_write_mb_s'])},
-            {commaInt(j['disk_read_mb_s'])},
-            {commaInt(j['disk_write_mb_s'])},
-            {commaInt(j['net_fds'])},
-            '{j['version']}',
-            {int(j['stamp'])}
-        )
-        """
+        try:
+            content_insert = f"""
+            INSERT INTO nodeInfo (
 
-        self.cur.execute(content_insert)
+                host,tmp_plots,mv_channels,cpu_count,cpu_percent,bucket_sum_t,bucket_count,
+
+                swap_percent,
+
+                disk_percent_block,io_nvme_block,io_list_plmo,io_list_nfs,io_read_issues,
+
+                memory_percent,net_read_mb_s,net_write_mb_s,disk_read_mb_s,disk_write_mb_s,
+
+                net_fds,
+
+                version,chia_ver,
+
+                timen
+
+            ) VALUES(
+
+                '{hostname}',
+                {int(j['plotcount'])},
+                {int(j['movingcount'])},
+                {int(j['cpucount'])},
+                {float(j['cpu_percent'])},
+                {float(j['sizet'])},
+                {float(j['historyplots'])},
+                {float(j['swap_percent'])},
+
+                {txtBlock(j['disk_info'])},
+                {txtBlock(j['disk_nvme_io'])},
+                {txtBlock(j['movingdetail'])},
+                {txtBlock(j['nfsips'])},
+
+                {float(j['io_read_issues'])},
+                {float(j['memory_percent'])},
+                {commaInt(j['net_read_mb_s'])},
+                {commaInt(j['net_write_mb_s'])},
+                {commaInt(j['disk_read_mb_s'])},
+                {commaInt(j['disk_write_mb_s'])},
+                {commaInt(j['net_fds'])},
+                '{txtBlock(j['version'])}',
+                '{txtBlock(j['chia_ver'])}',
+                {int(datetime.now().timestamp())}
+            )
+            """
+
+            self.cur.execute(content_insert)
+
+        except sqlite3.OperationalError as r:
+            print(f"there is a things that doesnt work. {r}")
 
     def getNodes(self) -> list:
         block = """
-        SELECT * FROM sysio GROUP BY ip ORDER BY stamp DESC
+        SELECT * FROM nodeInfo ORDER BY timen DESC GROUP BY host 
         """
 
         list = self.cur.execute(block).fetchall()
